@@ -98,10 +98,13 @@ class AlastriaAuthService(AAlastriaAuthService):
             confirm_url="/alastria/alastria-auth/confirm",
         )
         rs.save()
+        network_data: NetworkDTO = NetworkClient(
+            service_host=settings.NETWORK_SERVICE_HOST
+        ).get_network_by_name(NetworksNames.AlastriaDefaultName)
         at: dict = AlastriaToken(
-            settings.ALASTRIA_PREFIX
+            network_data.did_prefix
             + AlastriaAuthService.get_did(settings.ISSUER_ADDRESS)[2:],
-            settings.ALASTRIA_NODE_IP,
+            network_data.node["path"],
             "/alastria/alastria-auth/confirm",
             settings.ALASTRIA_T_NETWORK_ID,
             1,
@@ -181,7 +184,10 @@ class AlastriaAuthService(AAlastriaAuthService):
             rs: RequestSession = RequestSession.objects.filter(
                 pk=request_session_id
             ).first()
-            format_did: str = settings.ALASTRIA_PREFIX + did[2:]
+            network_data: NetworkDTO = NetworkClient(
+                service_host=settings.NETWORK_SERVICE_HOST
+            ).get_network_by_name(NetworksNames.AlastriaDefaultName)
+            format_did: str = network_data.did_prefix + did[2:]
 
             return AlastriaAuthService.validate_request_session(
                 rs,
